<?php
/**
 * Email Styles
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/email-styles.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates/Emails
 * @version 3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Load colors.
$bg        = get_option( 'woocommerce_email_background_color' );
$body      = get_option( 'woocommerce_email_body_background_color' );
$base      = get_option( 'woocommerce_email_base_color' );
$base_text = wc_light_or_dark( $base, '#202020', '#ffffff' );
$text      = get_option( 'woocommerce_email_text_color' );

// Pick a contrasting color for links.
$link_color = wc_hex_is_light( $base ) ? $base : $base_text;

if ( wc_hex_is_light( $body ) ) {
	$link_color = wc_hex_is_light( $base ) ? $base_text : $base;
}

$bg_darker_10    = wc_hex_darker( $bg, 10 );
$body_darker_10  = wc_hex_darker( $body, 10 );
$base_lighter_20 = wc_hex_lighter( $base, 20 );
$base_lighter_40 = wc_hex_lighter( $base, 40 );
$text_lighter_20 = wc_hex_lighter( $text, 20 );
$text_lighter_40 = wc_hex_lighter( $text, 40 );

// !important; is a gmail hack to prevent styles being stripped if it doesn't like something.
// body{padding: 0;} ensures proper scale/positioning of the email in the iOS native email app.
?>
@media screen {
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 400;
		src: local('Fira Sans Regular'), local('FiraSans-Regular'), url(https://fonts.gstatic.com/s/firasans/v8/va9E4kDNxMZdWfMOD5Vvl4jLazX3dA.woff2) format('woff2');
		unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 400;
		src: local('Fira Sans Regular'), local('FiraSans-Regular'), url(https://fonts.gstatic.com/s/firasans/v8/va9E4kDNxMZdWfMOD5Vvk4jLazX3dGTP.woff2) format('woff2');
		unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 500;
		src: local('Fira Sans Medium'), local('FiraSans-Medium'), url(https://fonts.gstatic.com/s/firasans/v8/va9B4kDNxMZdWfMOD5VnZKveRhf6Xl7Glw.woff2) format('woff2');
		unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 500;
		src: local('Fira Sans Medium'), local('FiraSans-Medium'), url(https://fonts.gstatic.com/s/firasans/v8/va9B4kDNxMZdWfMOD5VnZKveQhf6Xl7Gl3LX.woff2) format('woff2');
		unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 700;
		src: local('Fira Sans Bold'), local('FiraSans-Bold'), url(https://fonts.gstatic.com/s/firasans/v8/va9B4kDNxMZdWfMOD5VnLK3eRhf6Xl7Glw.woff2) format('woff2');
		unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 700;
		src: local('Fira Sans Bold'), local('FiraSans-Bold'), url(https://fonts.gstatic.com/s/firasans/v8/va9B4kDNxMZdWfMOD5VnLK3eQhf6Xl7Gl3LX.woff2) format('woff2');
		unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 800;
		src: local('Fira Sans ExtraBold'), local('FiraSans-ExtraBold'), url(https://fonts.gstatic.com/s/firasans/v8/va9B4kDNxMZdWfMOD5VnMK7eRhf6Xl7Glw.woff2) format('woff2');
		unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
	}
	@font-face {
		font-family: 'Fira Sans';
		font-style: normal;
		font-weight: 800;
		src: local('Fira Sans ExtraBold'), local('FiraSans-ExtraBold'), url(https://fonts.gstatic.com/s/firasans/v8/va9B4kDNxMZdWfMOD5VnMK7eQhf6Xl7Gl3LX.woff2) format('woff2');
		unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
	}
}

#outlook a {
	padding: 0;
}

.ReadMsgBody,
.ExternalClass {
	width: 100%;
}

.ExternalClass,
.ExternalClass p,
.ExternalClass td,
.ExternalClass div,
.ExternalClass span,
.ExternalClass font {
	line-height: 100%;
}

div[style*="margin: 14px 0"],
div[style*="margin: 16px 0"] {
	margin: 0 !important;
}

table,
td {
	mso-table-lspace: 0;
	mso-table-rspace: 0;
}

table,
tr,
td {
	border-collapse: collapse;
}

body,
td,
th,
p,
div,
li,
a,
span {
	-webkit-text-size-adjust: 100%;
	-ms-text-size-adjust: 100%;
	mso-line-height-rule: exactly;
}

img {
	border: 0;
	outline: none;
	line-height: 100%;
	text-decoration: none;
	-ms-interpolation-mode: bicubic;
}

a[x-apple-data-detectors] {
	color: inherit !important;
	text-decoration: none !important;
}

body {
	margin: 0;
	padding: 0;
	width: 100% !important;
	-webkit-font-smoothing: antialiased;
}

.pc-gmail-fix {
	display: none;
	display: none !important;
}

@media screen and (min-width: 621px) {
	.pc-email-container {
		width: 620px !important;
	}
}

@media screen and (max-width:620px) {
	.pc-sm-p-30-10 {
		padding: 30px 10px !important
	}
	.pc-sm-fs-30 {
		font-size: 30px !important
	}
	.pc-sm-fs-20 {
		font-size: 20px !important
	}
	.pc-sm-fs-18 {
		font-size: 18px !important
	}
	.pc-sm-mw-100pc {
		min-width: 100% !important
	}
}

@media screen and (max-width:525px) {
	.pc-xs-p-25-0 {
		padding: 25px 0 !important
	}
	.pc-xs-fs-16 {
		font-size: 16px !important
	}
	.pc-xs-br-disabled br {
		display: none !important
	}
}
<?php
